@@ -29,7 +29,7 @@ int  reposition_client(t_session *session, t_ip_addr *ip_address);
 int  mark_client_for_removal(t_session *session, int delay);
 void check_remove_deadlines(t_config *config, time_t now);
 int  remove_client(t_session *session, bool free_session);
-int  connection_allowed(t_ip_addr *ip, int maxperip, int maxtotal);
+int  connection_allowed(t_ip_addr *ip, bool ip_of_proxy, int max_per_ip, int max_total);
 int  disconnect_clients(t_config *config);
 bool client_is_flooding(t_session *session);
 void check_flooding(t_config *config);
