@@ -374,74 +374,6 @@ void url_decode(char *str) {
 	*dest = '\0';
 }
 
-/* Encode string to UTF-8
-int utf8_encode(char *str, char **encoded) {
-	int len = 0, extra = 0;
-	unsigned char *r, *w;
-
-	if (str == NULL) {
-		return -1;
-	}
-
-	r = (unsigned char*)str;
-	while (*r != '\0') {
-		len++;
-		if (*r >= 0x80) {
-			extra++;
-		}
-		r++;
-	}
-
-	if (extra == 0) {
-		*encoded = NULL;
-		return 0;
-	} else if ((*encoded = (char*)malloc(len + extra + 1)) == NULL) {
-		return -1;
-	}
-
-	r = (unsigned char*)str;
-	w = (unsigned char*)*encoded;
-	while (*r != '\0') {
-		if (*r >= 0xC0) {
-			*(w++) = 0xC3;
-			*(w++) = *(r++) - 0x40;
-			continue;
-		} else if (*r >= 0x80) {
-			*(w++) = 0xC2;
-		}
-		*(w++) = *(r++);
-	}
-	*w = '\0';
-
-	return extra;
-}
-*/
-
-/* Decode UTF-8 string
- */
-void utf8_decode(char *str) {
-	unsigned char *r, *w;
-
-	if (str == NULL) {
-		return;
-	}
-
-	r = (unsigned char*)str;
-	w = (unsigned char*)str;
-	while (*r != '\0') {
-		if ((*r == 0xC2) && (*(r+1) >= 0x80) && (*(r+1) < 0xC0)) {
-			r++;
-			*(w++) = *(r++);
-		} else if ((*r == 0xC3) && (*(r+1) >= 0x80) && (*(r+1) < 0xC0)) {
-			r++;
-			*(w++) = *(r++) + 0x40;
-		} else {
-			*(w++) = *(r++);
-		}
-	}
-	*w = '\0';
-}
-
 /* Scan for characters with ASCII value < 32.
  */
 bool forbidden_chars_present(char *str) {
